@@ -1,6 +1,6 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
 /*
- * Copyright (C) 2002 Mikael Hallendal <micke@imendio.com>
+ * Copyright (C) 2003 Shaun McCance <shaunm@gnome.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -17,7 +17,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: Mikael Hallendal <micke@imendio.com>
+ * Author: Shaun McCance <shaunm@gnome.org>
  */
 
 #ifndef __YELP_CACHE_H__
@@ -29,8 +29,8 @@
 
 void           yelp_cache_init          (void);
 
-const gchar *  yelp_cache_lookup        (const gchar *path);
+GObject *      yelp_cache_lookup        (const gchar *path);
 
 void           yelp_cache_add           (const gchar *path,
-                                         const gchar *html);
+					 GObject     *object);
 #endif /* __YELP_CACHE_H__ */
